@@ -45,7 +45,7 @@ on_files_listed (GnomeVFSAsyncHandle *handle,
     if (result != GNOME_VFS_OK && result != GNOME_VFS_ERROR_EOF)
     {
         DEBUG ('l', "Directory listing failed, %s\n", gnome_vfs_result_to_string (result));
-        dir->state = DIR_STATE_EMPTY;
+        dir->state = GnomeCmdDir::STATE_EMPTY;
         dir->list_result = result;
     }
 
@@ -59,7 +59,7 @@ on_files_listed (GnomeVFSAsyncHandle *handle,
 
     if (result == GNOME_VFS_ERROR_EOF)
     {
-        dir->state = DIR_STATE_LISTED;
+        dir->state = GnomeCmdDir::STATE_LISTED;
         dir->list_result = GNOME_VFS_OK;
         DEBUG('l', "All files listed\n");
     }
@@ -70,7 +70,7 @@ static gboolean update_list_progress (GnomeCmdDir *dir)
 {
     DEBUG ('l', "Checking list progress...\n");
 
-    if (dir->state == DIR_STATE_LISTING)
+    if (dir->state == GnomeCmdDir::STATE_LISTING)
     {
         gchar *msg = g_strdup_printf (ngettext ("%d file listed", "%d files listed", dir->list_counter), dir->list_counter);
         gtk_label_set_text (GTK_LABEL (dir->label), msg);
@@ -92,7 +92,7 @@ inline void visprog_list (GnomeCmdDir *dir)
 
     GnomeVFSFileInfoOptions infoOpts = (GnomeVFSFileInfoOptions) (GNOME_VFS_FILE_INFO_FOLLOW_LINKS | GNOME_VFS_FILE_INFO_GET_MIME_TYPE);
 
-    GnomeVFSURI *uri = gnome_cmd_file_get_uri (GNOME_CMD_FILE (dir));
+    GnomeVFSURI *uri = GNOME_CMD_FILE (dir)->get_uri();
     gchar *uri_str = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE);
 
     DEBUG('l', "visprog_list: %s\n", uri_str);
@@ -115,23 +115,16 @@ inline void blocking_list (GnomeCmdDir *dir)
 {
     GnomeVFSFileInfoOptions infoOpts = (GnomeVFSFileInfoOptions) (GNOME_VFS_FILE_INFO_FOLLOW_LINKS | GNOME_VFS_FILE_INFO_GET_MIME_TYPE);
 
-    gchar *uri_str = gnome_cmd_file_get_uri_str (GNOME_CMD_FILE (dir));
+    gchar *uri_str = GNOME_CMD_FILE (dir)->get_uri_str();
     DEBUG('l', "blocking_list: %s\n", uri_str);
 
+    dir->infolist = NULL;
     dir->list_result = gnome_vfs_directory_list_load (&dir->infolist, uri_str, infoOpts);
 
     g_free (uri_str);
 
-    if (dir->list_result == GNOME_VFS_OK)
-    {
-        dir->state = DIR_STATE_LISTED;
-        dir->done_func (dir, dir->infolist, dir->list_result);
-    }
-    else
-    {
-        dir->state = DIR_STATE_EMPTY;
-        dir->done_func (dir, NULL, dir->list_result);
-    }
+    dir->state = dir->list_result==GNOME_VFS_OK ? GnomeCmdDir::STATE_LISTED : GnomeCmdDir::STATE_EMPTY;
+    dir->done_func (dir, dir->infolist, dir->list_result);
 }
 
 
@@ -143,7 +136,7 @@ void dirlist_list (GnomeCmdDir *dir, gboolean visprog)
     dir->list_handle = NULL;
     dir->list_counter = 0;
     dir->list_result = GNOME_VFS_OK;
-    dir->state = DIR_STATE_LISTING;
+    dir->state = GnomeCmdDir::STATE_LISTING;
 
     if (!visprog)
     {
@@ -157,7 +150,7 @@ void dirlist_list (GnomeCmdDir *dir, gboolean visprog)
 
 void dirlist_cancel (GnomeCmdDir *dir)
 {
-    dir->state = DIR_STATE_EMPTY;
+    dir->state = GnomeCmdDir::STATE_EMPTY;
     dir->list_result = GNOME_VFS_OK;
 
     DEBUG('l', "Calling async_cancel\n");
