@@ -32,11 +32,6 @@ using namespace std;
 static GtkCListClass *parent_class = NULL;
 
 
-struct GnomeCmdCListPrivate
-{
-};
-
-
 /*******************************************
  * TEST TEST TEST
  ****/
@@ -54,61 +49,6 @@ struct GnomeCmdCListPrivate
                     (((row) + 1) * CELL_SPACING) + \
                     (clist)->voffset)
 
-/* returns the row index from a y pixel location in the
- * context of the clist's voffset */
-#define ROW_FROM_YPIXEL(clist, y)  (((y) - (clist)->voffset) / \
-                    ((clist)->row_height + CELL_SPACING))
-
-/* gives the left pixel of the given column in context of
- * the clist's hoffset */
-#define COLUMN_LEFT_XPIXEL(clist, colnum)  ((clist)->column[(colnum)].area.x + \
-                        (clist)->hoffset)
-
-/* returns the column index from a x pixel location in the
- * context of the clist's hoffset */
-inline gint COLUMN_FROM_XPIXEL (GtkCList * clist, gint x)
-{
-    for (gint i = 0; i < clist->columns; i++)
-        if (clist->column[i].visible)
-        {
-            gint cx = clist->column[i].area.x + clist->hoffset;
-
-            if (x >= (cx - (COLUMN_INSET + CELL_SPACING)) &&  x <= (cx + clist->column[i].area.width + COLUMN_INSET))
-                return i;
-        }
-
-    // no match
-    return -1;
-}
-
-
-/* returns the top pixel of the given row in the context of
- * the list height */
-#define ROW_TOP(clist, row)        (((clist)->row_height + CELL_SPACING) * (row))
-
-/* returns the left pixel of the given column in the context of
- * the list width */
-#define COLUMN_LEFT(clist, colnum) ((clist)->column[(colnum)].area.x)
-
-// returns the total height of the list
-#define LIST_HEIGHT(clist)         (((clist)->row_height * ((clist)->rows)) + \
-                                    (CELL_SPACING * ((clist)->rows + 1)))
-
-
-// returns the total width of the list
-inline gint LIST_WIDTH (GtkCList * clist)
-{
-  gint last_column;
-
-  for (last_column = clist->columns - 1;
-       last_column >= 0 && !clist->column[last_column].visible; last_column--);
-
-  if (last_column >= 0)
-    return clist->column[last_column].area.x + clist->column[last_column].area.width + COLUMN_INSET + CELL_SPACING;
-
-  return 0;
-}
-
 // returns the GList item for the nth row
 #define    ROW_ELEMENT(clist, row)    (((row) == (clist)->rows - 1) ? (clist)->row_list_end : \
                                                                       g_list_nth ((clist)->row_list, (row)))
@@ -220,7 +160,7 @@ draw_cell_pixmap (GdkWindow    *window,
     if (y + height > clip_rectangle->y + clip_rectangle->height)
         height = clip_rectangle->y + clip_rectangle->height - y;
 
-    gdk_draw_pixmap (window, fg_gc, pixmap, xsrc, ysrc, x, y, width, height);
+    gdk_draw_drawable (window, fg_gc, pixmap, xsrc, ysrc, x, y, width, height);
     gdk_gc_set_clip_origin (fg_gc, 0, 0);
     if (mask)
         gdk_gc_set_clip_mask (fg_gc, NULL);
@@ -319,8 +259,7 @@ static void draw_row (GtkCList *clist, GdkRectangle *area, gint row, GtkCListRow
     if (area)
     {
         rect = &intersect_rectangle;
-        if (gdk_rectangle_intersect (area, &cell_rectangle,
-                                     &intersect_rectangle))
+        if (gdk_rectangle_intersect (area, &cell_rectangle, &intersect_rectangle))
             gdk_draw_rectangle (clist->clist_window,
                                 widget->style->base_gc[GTK_STATE_NORMAL],
                                 TRUE,
@@ -406,8 +345,7 @@ static void draw_row (GtkCList *clist, GdkRectangle *area, gint row, GtkCListRow
         if (area && !gdk_rectangle_intersect (area, &clip_rectangle, &intersect_rectangle))
             continue;
 
-        gdk_draw_rectangle (clist->clist_window, bg_gc, TRUE,
-                            rect->x, rect->y, rect->width, rect->height);
+        gdk_draw_rectangle (clist->clist_window, bg_gc, TRUE, rect->x, rect->y, rect->width, rect->height);
 
         clip_rectangle.x += COLUMN_INSET + CELL_SPACING;
         clip_rectangle.width -= (2 * COLUMN_INSET + CELL_SPACING + (i == last_column) * CELL_SPACING);
@@ -429,12 +367,12 @@ static void draw_row (GtkCList *clist, GdkRectangle *area, gint row, GtkCListRow
         switch (clist_row->cell[i].type)
         {
             case GTK_CELL_PIXMAP:
-                gdk_window_get_size (GTK_CELL_PIXMAP (clist_row->cell[i])->pixmap, &pixmap_width, &height);
+                gdk_drawable_get_size (GTK_CELL_PIXMAP (clist_row->cell[i])->pixmap, &pixmap_width, &height);
                 width += pixmap_width;
                 break;
 
             case GTK_CELL_PIXTEXT:
-                gdk_window_get_size (GTK_CELL_PIXTEXT (clist_row->cell[i])->pixmap, &pixmap_width, &height);
+                gdk_drawable_get_size (GTK_CELL_PIXTEXT (clist_row->cell[i])->pixmap, &pixmap_width, &height);
                 width += pixmap_width + GTK_CELL_PIXTEXT (clist_row->cell[i])->spacing;
                 break;
 
@@ -492,7 +430,7 @@ static void draw_row (GtkCList *clist, GdkRectangle *area, gint row, GtkCListRow
                                      offset,
                                      row_rectangle.y + row_center_offset + clist_row->cell[i].vertical,
                                      layout);
-                    g_object_unref (G_OBJECT (layout));
+                    g_object_unref (layout);
                     gdk_gc_set_clip_rectangle (fg_gc, NULL);
                 }
                 break;
@@ -528,7 +466,7 @@ static void draw_row (GtkCList *clist, GdkRectangle *area, gint row, GtkCListRow
  ****/
 static void on_hadj_value_changed (GtkAdjustment *adjustment, GnomeCmdCList *clist)
 {
-    gtk_widget_draw(GTK_WIDGET(clist), NULL);
+    gtk_widget_draw (GTK_WIDGET (clist), NULL);
 }
 
 
@@ -544,9 +482,8 @@ static void on_realize (GtkCList *clist, gpointer data)
         if (clist->column[i].button)
             GTK_WIDGET_UNSET_FLAGS (clist->column[i].button, GTK_CAN_FOCUS);
 
-    if (GTK_CLIST(clist)->hadjustment)
-        gtk_signal_connect_after(GTK_OBJECT(GTK_CLIST(clist)->hadjustment), "value-changed",
-            GTK_SIGNAL_FUNC(on_hadj_value_changed), clist);
+    if (GTK_CLIST (clist)->hadjustment)
+        g_signal_connect_after (GTK_CLIST(clist)->hadjustment, "value-changed", GTK_SIGNAL_FUNC (on_hadj_value_changed), clist);
 }
 
 
@@ -590,11 +527,11 @@ static void init (GnomeCmdCList *clist)
     clist->drag_motion_row = -1;
 
     gtk_clist_set_selection_mode (GTK_CLIST (clist), GTK_SELECTION_SINGLE);
-    
+
     GTK_CLIST (clist)->focus_row = 0;
 
-    gtk_signal_connect_after (GTK_OBJECT (clist), "scroll-vertical", GTK_SIGNAL_FUNC (on_scroll_vertical), NULL);
-    gtk_signal_connect (GTK_OBJECT (clist), "realize", GTK_SIGNAL_FUNC (on_realize), NULL);
+    g_signal_connect_after (clist, "scroll-vertical", G_CALLBACK (on_scroll_vertical), NULL);
+    g_signal_connect (clist, "realize", G_CALLBACK (on_realize), NULL);
 }
 
 
@@ -628,7 +565,7 @@ GtkType gnome_cmd_clist_get_type ()
 
 GtkWidget *gnome_cmd_clist_new_with_titles (gint columns, gchar **titles)
 {
-    GnomeCmdCList *clist = (GnomeCmdCList *) g_object_new (gnome_cmd_clist_get_type(), "n-columns", columns, NULL);
+    GnomeCmdCList *clist = (GnomeCmdCList *) g_object_new (GNOME_CMD_TYPE_CLIST, "n-columns", columns, NULL);
 
     for (gint i=0; i<columns; i++)
         gtk_clist_set_column_auto_resize (GTK_CLIST (clist), i, TRUE);
