@@ -109,7 +109,8 @@ GnomeCmdData::Options::Options(const Options &cfg)
     use_internal_viewer = cfg.use_internal_viewer;
     editor = g_strdup (cfg.editor);
     differ = g_strdup (cfg.differ);
-    term = g_strdup (cfg.term);
+    termopen = g_strdup (cfg.termopen);
+    termexec = g_strdup (cfg.termexec);
     fav_apps = cfg.fav_apps;
     device_only_icon = cfg.device_only_icon;
     skip_mounting = cfg.skip_mounting;
@@ -164,7 +165,8 @@ GnomeCmdData::Options &GnomeCmdData::Options::operator = (const Options &cfg)
         use_internal_viewer = cfg.use_internal_viewer;
         editor = g_strdup (cfg.editor);
         differ = g_strdup (cfg.differ);
-        term = g_strdup (cfg.term);
+        termopen = g_strdup (cfg.termopen);
+        termexec = g_strdup (cfg.termexec);
         fav_apps = cfg.fav_apps;
         device_only_icon = cfg.device_only_icon;
         skip_mounting = cfg.skip_mounting;
@@ -1204,7 +1206,8 @@ void GnomeCmdData::load()
     options.viewer = gnome_cmd_data_get_string ("/programs/viewer", "gedit %s");
     options.editor = gnome_cmd_data_get_string ("/programs/editor", "gedit %s");
     options.differ = gnome_cmd_data_get_string ("/programs/differ", "meld %s");
-    options.term   = gnome_cmd_data_get_string ("/programs/terminal", "xterm -hold -e %s");
+    options.termopen = gnome_cmd_data_get_string ("/programs/terminal_open", "xterm -hold");
+    options.termexec = gnome_cmd_data_get_string ("/programs/terminal_exec", "xterm -hold -e %s");
 
     use_gcmd_block = gnome_cmd_data_get_bool ("/programs/use_gcmd_block", FALSE);
 
@@ -1624,7 +1627,8 @@ void GnomeCmdData::save()
     gnome_cmd_data_set_string ("/programs/viewer", options.viewer);
     gnome_cmd_data_set_string ("/programs/editor", options.editor);
     gnome_cmd_data_set_string ("/programs/differ", options.differ);
-    gnome_cmd_data_set_string ("/programs/terminal", options.term);
+    gnome_cmd_data_set_string ("/programs/terminal_open", options.termopen);
+    gnome_cmd_data_set_string ("/programs/terminal_exec", options.termexec);
 
     gnome_cmd_data_set_bool   ("/programs/use_gcmd_block", use_gcmd_block);
 
