@@ -1186,8 +1186,8 @@ void command_execute (GtkMenuItem *menuitem, gpointer command)
     g_shell_parse_argv (cmd.c_str(), &argc, &argv, NULL);
     if (!g_spawn_async (gnome_cmd_dir_is_local (dir) ? dir_path.c_str() : NULL, argv, NULL, G_SPAWN_SEARCH_PATH, NULL, NULL, NULL, &error))
         gnome_cmd_error_message (_("Unable to execute command."), error);
-    g_strfreev (argv);
 
+    g_strfreev (argv);
     g_list_free (sfl);
 }
 
@@ -1204,35 +1204,50 @@ void command_open_terminal__internal (GtkMenuItem *menuitem, gpointer not_used)
         command_open_terminal (menuitem, NULL);
 }
 
-
+/** 
+ * Executes the command stored in gnome_cmd_data.options.termopen in the
+ * active directory.
+ */
 void command_open_terminal (GtkMenuItem *menuitem, gpointer not_used)
 {
+    gint argc;
+    gchar **argv;
+    gchar *command;
     gchar *dpath = GNOME_CMD_FILE (get_fs (ACTIVE)->get_directory())->get_real_path();
+    GError *error = NULL;
 
-    if (gnome_execute_terminal_shell (dpath, NULL) == -1)
-        gnome_cmd_show_message (NULL, _("Unable to open terminal"), g_strerror (errno));
+    command = g_strdup (gnome_cmd_data.options.termopen);
+
+    DEBUG ('g', "running: %s\n", command);
+
+    g_shell_parse_argv (command, &argc, &argv, NULL);
+    if (!g_spawn_async (dpath, argv, NULL, G_SPAWN_SEARCH_PATH, NULL, NULL, NULL, &error))
+        gnome_cmd_error_message (_("Unable to execute command."), error);
+
+    g_strfreev (argv);
+    g_free (command);
     g_free (dpath);
 }
 
-
+/** 
+ * Combines the command stored in gnome_cmd_data.options.termopen with a
+ * command for a GUI for root login screen. The command is executed in
+ * the active directory afterwards.
+ */
 void command_open_terminal_as_root (GtkMenuItem *menuitem, gpointer not_used)
 {
+    
     int argc = 1;
-    char **argv = g_new0 (char *, argc+1);
+    char **argv = g_new0 (char *, argc+1);  //initialize argv
+    gchar *command;
 
-    argv[0] = gnome_util_user_shell ();
+    command = g_strdup (gnome_cmd_data.options.termopen);
+    // Parse the termopen string to get the number of arguments in argc
+    g_shell_parse_argv (command, &argc, &argv, NULL);
+    g_free (argv);
 
-    gnome_prepend_terminal_to_vector (&argc, &argv);
-
-    // Insert quotes into the string of argv to get, e.g.
-    // /usr/bin/gksu 'roxterm -e /bin/bash' instead of
-    // /usr/bin/gksu roxterm -e /bin/bash
-    // (the second case doesn't work in some cases)
-    gchar *cmd = g_strjoinv (" ", argv);
-    g_strfreev (argv);
-    argc = 1;
     argv = g_new0 (char *, argc+1);
-    argv[0] = cmd;
+    argv[0] = command;
 
     if (gnome_cmd_prepend_su_to_vector (argc, argv))
     {
@@ -1247,7 +1262,8 @@ void command_open_terminal_as_root (GtkMenuItem *menuitem, gpointer not_used)
     else
         gnome_cmd_show_message (NULL, _("xdg-su, gksu, gnomesu, kdesu or beesu is not found."));
 
-    g_strfreev (argv);
+    g_free (argv);
+    g_free (command);
 }
 
 
