@@ -39,8 +39,9 @@
 #include "utils.h"
 #include "dict.h"
 
-#ifdef HAVE_GSF
-#include <gsf/gsf-doc-meta-data.h>
+#ifdef HAVE_GSF_1_14_26
+#include <gsf/gsf.h>
+#elif HAVE_GSF
 #include <gsf/gsf-infile.h>
 #include <gsf/gsf-infile-msole.h>
 #include <gsf/gsf-infile-zip.h>
@@ -257,7 +258,7 @@ inline void process_opendoc_infile(GsfInfile *infile, GnomeCmdFileMetadata *meta
     else
         g_error_free (err);
 
-    g_object_unref (G_OBJECT (sections));
+    g_object_unref (sections);
 }
 
 
@@ -271,7 +272,7 @@ inline void process_msole_summary(GsfInput *input, GnomeCmdFileMetadata *metadat
     else
         g_error_free (err);
 
-    g_object_unref (G_OBJECT (sections));
+    g_object_unref (sections);
 }
 
 
@@ -326,7 +327,7 @@ inline void process_msole_infile(GsfInfile *infile, GnomeCmdFileMetadata *metada
     // if (src)
     // {
         // process_msole_summary (src, metadata);
-        // g_object_unref (G_OBJECT(src));
+        // g_object_unref (src);
     // }
 
     // src = gsf_infile_child_by_name (infile, "\005DocumentSummaryInformation");
@@ -334,7 +335,7 @@ inline void process_msole_infile(GsfInfile *infile, GnomeCmdFileMetadata *metada
     // if (src)
     // {
         // process_msole_summary (src, metadata);
-        // g_object_unref (G_OBJECT(src));
+        // g_object_unref (src);
     // }
 
     // src = gsf_infile_child_by_name (infile, "SfxDocumentInfo");
@@ -342,7 +343,7 @@ inline void process_msole_infile(GsfInfile *infile, GnomeCmdFileMetadata *metada
     // if (src)
     // {
         // process_msole_SO (src, metadata);
-        // g_object_unref (G_OBJECT(src));
+        // g_object_unref (src);
     // }
 
     for (gint i=0; i<gsf_infile_num_children (infile); i++)
@@ -361,7 +362,7 @@ inline void process_msole_infile(GsfInfile *infile, GnomeCmdFileMetadata *metada
             if (src)
             {
                 process_msole_summary (src, metadata);
-                g_object_unref (G_OBJECT (src));
+                g_object_unref (src);
             }
 
             continue;
@@ -374,7 +375,7 @@ inline void process_msole_infile(GsfInfile *infile, GnomeCmdFileMetadata *metada
             if (src)
             {
                 process_msole_SO (src, metadata);
-                g_object_unref (G_OBJECT (src));
+                g_object_unref (src);
             }
 
             continue;
@@ -469,10 +470,10 @@ void gcmd_tags_libgsf_load_metadata(GnomeCmdFile *f)
 
     f->metadata->mark_as_accessed(TAG_DOC);
 
-    if (!gnome_cmd_file_is_local(f))  return;
+    if (!f->is_local())  return;
 
     GError *err = NULL;
-    gchar *fname = gnome_cmd_file_get_real_path (f);
+    gchar *fname = f->get_real_path();
 
     DEBUG('t', "Loading doc metadata for '%s'\n", fname);
 
@@ -500,11 +501,11 @@ void gcmd_tags_libgsf_load_metadata(GnomeCmdFile *f)
             process_opendoc_infile(infile, f->metadata);
 
     if (infile)
-        g_object_unref (G_OBJECT (infile));
+        g_object_unref (infile);
 
     if (err)
         g_error_free (err);
 
-    g_object_unref (G_OBJECT (input));
+    g_object_unref (input);
 #endif
 }
